Skip to contents

Greedy-sampling-in-output-space acquisition function.

The score is the minimum absolute distance between a candidate prediction and an already observed target value.

Creates a new GSy acquisition function.

Arguments

surrogate

(NULL | mlr3mbo::SurrogateLearner)
Surrogate used for mean predictions.