Skip to contents

Abstract base class for pool samplers that are driven by an ALDistance.

The wrapped distance object is stored directly and its paradox::ParamSet is forwarded as the sampler parameter set.

Creates a new distance-based space sampler.

Arguments

id

(character(1))
Identifier of the sampler.

distance

(ALDistance)
Distance object used by the sampler.

Fields

distance

(ALDistance) Wrapped distance object.