Skip to contents

This function complements mlr_al_distances with a construction helper in the spirit of mlr_sugar.

Usage

clx_ald(.key, ...)

Arguments

.key

(character(1))
Key passed to mlr_al_distances.

...

(named list())
Named arguments passed to the constructor, to the parameter set, or to public fields. See mlr3misc::dictionary_sugar_get() for details.

Value

ALDistance.

Examples

clx_ald("standardize")
#> <ALDistanceStandardize:standardize>