Skip to contents

This function complements mlr_space_samplers with a construction helper in the spirit of mlr_sugar.

Usage

clx_sps(.key, ...)

Arguments

.key

(character(1))
Key passed to mlr_space_samplers.

...

(named list())
Named arguments passed to the constructor, to the parameter set, or to public fields. See mlr3misc::dictionary_sugar_get() for details.

Value

SpaceSampler.

Examples

clx_sps("uniform")
#> <SpaceSamplerUniform:uniform>