Approximates the integral of prediction variance over the domain. This is the continuous version of mean variance, accounting for domain volume.
Usage
metric_integrated_variance(
archive,
surrogate = NULL,
grid = NULL,
search_space = NULL,
...
)Arguments
- archive
(bbotk::ArchiveBatch)
The archive (may be used for normalization).- surrogate
(mlr3mbo::Surrogate)
The fitted surrogate model.- grid
(
data.table|NULL)
Points at which to evaluate variance. IfNULL, generates a default grid from the search space.- search_space
(paradox::ParamSet |
NULL)
Used to generate grid if not provided.- ...
Ignored.