Skip to contents

Wrapper sampler that applies several SpaceSampler objects one after the other to thin down a pool.

The target_size_fn hyperparameter is a function taking scalar pool_size and scalar n and returning one target size per wrapped sampler. The returned sequence must be non-increasing, each entry must be at most pool_size, and the final entry must equal n.

Creates a new chained space sampler.

Format

R6::R6Class object inheriting from SpaceSampler.

Arguments

samplers

(named list() of SpaceSampler)
Samplers to apply in sequence.

Fields

samplers

(named list() of SpaceSampler) Wrapped samplers.

Construction

clx_sps("chain")