Skip to contents

Greedy-sampling-in-input-space sampler.

Without known_pool, the first selected point is the pool point minimizing the sum of squared distances to all other pool points. Subsequent points are chosen by farthest-first traversal, maximizing the minimum squared distance to the already-selected or known points.

Creates a new GSx space sampler.

Format

R6::R6Class object inheriting from SpaceSamplerDistance.

Arguments

distance

(ALDistance)
Distance used for the GSx selection rule.

Construction

clx_sps("gsx")