Skip to contents

Sampler that draws Latin hypercube designs from a search space.

This sampler only samples from the search space directly and errors when a pool is supplied.

Creates a new LHS space sampler.

Format

R6::R6Class object inheriting from SpaceSampler.

Construction

clx_sps("lhs")