Abstract base class for active-learning distances based on Euclidean distances in a geometry space.
Subclasses implement how the pool or search space determines geometry-space scaling and how reference and query points are transformed into that same space.
Subclasses must implement the following methods:
private$.fit_geometry(xdt, search_space): Fit the geometry from the pool and search space, or from the search space only whenxdtisNULL. The result must contain an integerdimensiongiving the number of geometry columns.private$.transform(xdt, state): Transform query points into the geometry space. The result must be a matrix with one row per query point andstate$dimensioncolumns.
Fields
dimension(
integer(1)|NULL) Dimension of the fitted geometry space.reference_embedding(
matrix()|NULL) Current reference points transformed into the fitted geometry space.NULLif the distance has not been fitted or reference points have not been set.
See also
Other ALDistance:
ALDistance,
mlr_al_distances,
mlr_al_distances_affine,
mlr_al_distances_gower,
mlr_al_distances_standardize