Greedy-sampling-in-input-space acquisition function using an ALDistance.
The score is the distance to the nearest already evaluated reference point.
Creates a new distance-aware GSx acquisition function.
Arguments
- surrogate
(
NULL| mlr3mbo::Surrogate)
Optional surrogate. Only used to derive the acquisition domain and archive reference points.- al_distance
(ALDistance |
NULL)
Distance used for input-space scores.
See also
Other Acquisition Function:
AcqFunctionDist,
AcqFunctionDistIDEAL,
AcqFunctionDistIGS,
AcqFunctionGSy,
SurrogateNull