Objective Function Based on a Candidate Pool and R Function
Source:R/ObjectivePoolRFun.R
ObjectivePoolRFun.RdAn ObjectivePoolAbstract where matched pool rows are evaluated by a user-supplied R function.
Creates a new instance of this R6 class.
Arguments
- pool
(
data.frame|data.table)
Candidate pool containing one row per admissible configuration. Must contain all domain columns. Extra columns are allowed and are passed tofun.- fun
(
function)
R function that evaluates matched pool rows. It must accept at least one argument, the matched pool rows, and return the codomain values as adata.table,data.frame, orlistthat can be converted to adata.tableusingrbindlist.- domain
(paradox::ParamSet)
Parameter set describing the input space.- codomain
(paradox::ParamSet)
Parameter set describing the output space.- id
(
character(1))
Identifier for the objective.- properties
(
character())
Objective properties such as"deterministic"or"noisy".- constants
(paradox::ParamSet)
Constant parameters that are not subject to tuning.- packages
(
character())
Packages required to evaluatefun.- check_values
(
logical(1))
Whether to check validity of input configurations against the domain.