Abstract base class for pool samplers that are driven by an ALDistance.
The wrapped distance object is stored directly and its paradox::ParamSet is forwarded as the sampler parameter set.
Creates a new distance-based space sampler.
Arguments
- id
(
character(1))
Identifier of the sampler.- distance
(ALDistance)
Distance object used by the sampler.
Fields
distance(ALDistance) Wrapped distance object.
See also
Other SpaceSampler:
SpaceSampler,
mlr_space_samplers,
mlr_space_samplers_chain,
mlr_space_samplers_conditional,
mlr_space_samplers_gsx,
mlr_space_samplers_kmeans,
mlr_space_samplers_kmedoids,
mlr_space_samplers_lhs,
mlr_space_samplers_relational_kmeans,
mlr_space_samplers_sobol,
mlr_space_samplers_uniform