Quantile Regression Learner with SE Prediction
Source:R/LearnerRegrQuantileSE.R
mlr_learners_regr.quantile_se.RdWraps a quantile regression learner and converts quantile predictions to SE.
Creates a new instance of this R6 class.
Arguments
- learner
(mlr3::LearnerRegr)
Base quantile learner. Must supportpredict_type = "quantiles".
Details
This learner:
Trains a base learner that supports quantile predictions
predicts lower and upper quantiles
SE prediction is the inter-quantile range multiplied by a factor
Parameters
The base learner's parameters are exposed with the base. prefix.
Own parameters:
quantile_response::numeric(1)
Quantile response to use for the prediction. Initialized to 0.5 (median).quantile_lower::numeric(1)
Lower quantile for SE estimation. Initialized to 0.1 (10th percentile).quantile_upper::numeric(1)
Upper quantile for SE estimation. Initialized to 0.9 (90th percentile).se_factor::numeric(1)|NULL
Factor to multiply the inter-quantile range to get the SE. The defaultNULLuses the normal-consistent factor1 / (qnorm(quantile_upper) - qnorm(quantile_lower)), so that under an approximately Gaussian predictive the SE estimates the predictive SD.
Fields
$wrapped:: mlr3::LearnerRegr
Read-only access to the wrapped base learner.