Greedy-sampling-in-input-space sampler.
Without known_pool, the first selected point is the pool point minimizing
the sum of squared distances to all other pool points. Subsequent points are
chosen by farthest-first traversal, maximizing the minimum squared distance to
the already-selected or known points.
Creates a new GSx space sampler.
Format
R6::R6Class object inheriting from SpaceSamplerDistance.
Arguments
- distance
(ALDistance)
Distance used for the GSx selection rule.
See also
Other SpaceSampler:
SpaceSampler,
SpaceSamplerDistance,
mlr_space_samplers,
mlr_space_samplers_chain,
mlr_space_samplers_conditional,
mlr_space_samplers_kmeans,
mlr_space_samplers_kmedoids,
mlr_space_samplers_lhs,
mlr_space_samplers_relational_kmeans,
mlr_space_samplers_sobol,
mlr_space_samplers_uniform